@@ -1,5 +1,5 @@
 /* This file is part of the yazpp toolkit.
- * Copyright (C) 1998-2008 Index Data and Mike Taylor
+ * Copyright (C) 1998-2009 Index Data and Mike Taylor
  * All rights reserved.
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -42,6 +42,7 @@ namespace yazpp_1 {
         GDU &operator=(const GDU &);
         Z_GDU *get() const;
         void move_away_gdu(ODR dst, Z_GDU **gdu);
+        int get_size();
     private:
         void base(Z_GDU *gdu, ODR o);
         Z_GDU *m_gdu;
@@ -53,6 +54,7 @@ namespace yazpp_1 {
 /*
  * Local variables:
  * c-basic-offset: 4
+ * c-file-style: "Stroustrup"
  * indent-tabs-mode: nil
  * End:
  * vim: shiftwidth=4 tabstop=8 expandtab
